@@ -10,6 +10,8 @@ constants.update({
         "app-key": "drilling-efficiency",
         "event-type": "scheduler",
         "query-limit": 3600,
+        "wits_query_fields": "_id, timestamp, collection, asset_id, company_id, app, metadata, data.state, "
+                             "data.weight_on_bit, data.rotary_rpm, data.rotary_torque, data.rop"
     },
     "drilling-efficiency": {
         "mse": {
