@@ -1,8 +1,8 @@
 import argparse
 import json
 import os
+from functools import cached_property
 
-from cached_property import cached_property
 from tqdm import tqdm
 
 from worker.data import operations
