@@ -75,11 +75,12 @@ def run_drillstring_and_create_wellbore(wits: dict, mud_flow_in: float = None) -
     )
 
 
-def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None) -> Union[Wellbore, None]:
+def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None, is_design: bool = False) -> Union[Wellbore, None]:
     """
     Get the wits record and create a wellbore
     :param wits: wits records in json format
     :param mud_flow_in: used to determine if under-reamer needs to be activated for hole enlargement
+    :param is_design: the mode of function
     :return: a wellbore
     """
     if wits is None:
@@ -92,7 +93,8 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None)
     if not casingstring_id:
         return None
 
-    casingstring = get_config_by_id(casingstring_id, collection="data.casing")
+    casing_data_source = "design.data.casing" if is_design else "data.casing"
+    casingstring = get_config_by_id(casingstring_id, collection=casing_data_source)
 
     if not casingstring:
         return None
@@ -140,23 +142,44 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None)
     bit_depth = get_data_by_path(wits, "data.bit_depth", float)
     hole_depth = get_data_by_path(wits, "data.hole_depth", float)
 
-    # setting cased-hole sections
     query = "{data.inner_diameter#gt#%s}" % casing_inner_diameter
     sort = "{data.inner_diameter:-1}"
-    casings = api_worker.get(path="/v1/data/corva", collection="data.casing", asset_id=asset_id, query=query, sort=sort, limit=100).data
+    previous_casings = api_worker.get(
+        path="/v1/data/corva",
+        collection=casing_data_source,
+        asset_id=asset_id,
+        query=query,
+        sort=sort,
+        limit=100
+    ).data
 
-    # ====== setting open-hole sections
-    sort = "{timestamp: -1}"
-    drillstrings = api_worker.get(path="/v1/data/corva", collection="data.drillstring", asset_id=asset_id, sort=sort, limit=100).data
+    drilling_data_source = "data.well-sections" if is_design else "data.drillstring"
+    sort = "{data.diameter:-1}" if is_design else "{timestamp: -1}"
 
-    drillstrings = [
-        next((string for string in drillstrings if (string.get("data", {}).get("components", [{}])[-1].get("size") or -1) > casing_outer_diameter), {})
-    ]
+    drill_sections = api_worker.get(
+        path="/v1/data/corva",
+        collection=drilling_data_source,
+        asset_id=asset_id,
+        sort=sort,
+        limit=100
+    ).data
 
-    hole = set_casings(casings)
-    smallest_cased_hole_diameter = hole.get_min_inner_diameter() or 100
+    # use data.well-sections to create hole
+    if is_design:
+        hole = create_hole_using_well_sections_data(
+            previous_casings,
+            drill_sections,
+            casing_bottom_depth
+        )
 
-    hole = add_open_holes(hole, drillstrings, smallest_cased_hole_diameter, hole_depth)
+    # use data.drillstring to create hole
+    else:
+        hole = create_hole_use_drillstring_data(
+            previous_casings,
+            drill_sections,
+            casing_outer_diameter,
+            hole_depth
+        )
 
     mud_flow_in = get_mud_flow_in(mud_flow_in, wits)
 
@@ -396,3 +419,65 @@ def get_mud_flow_in(mud_flow_in: Union[float, None], wits: dict) -> Union[float,
         return None
 
     return get_data_by_path(wits, "data.mud_flow_in", default=None)
+
+
+def create_hole_use_drillstring_data(
+        previous_casings: List[dict],
+        drillstrings: List[dict],
+        casing_outer_diameter: float,
+        hole_depth: float
+) -> Union[Hole, None]:
+    """
+    Create a hole using data.drillstring collection
+    :param previous_casings: previous casings data
+    :param drillstrings: drillstring data
+    :param casing_outer_diameter: outer diameter of casing in inch
+    :param hole_depth: bottom depth of the hole in ft
+    :return: a hole
+    """
+    drillstrings = [
+        string for string in drillstrings
+        if (string.get("data", {}).get("components", [{}])[-1].get("size") or -1) > casing_outer_diameter
+    ]
+
+    hole = set_casings(previous_casings)
+    smallest_cased_hole_diameter = hole.get_min_inner_diameter() or 100
+
+    return add_open_holes(hole, drillstrings, smallest_cased_hole_diameter, hole_depth)
+
+
+def create_hole_using_well_sections_data(
+        previous_casings: List[dict],
+        drill_sections: List[dict],
+        casing_bottom_depth: float
+) -> Union[Hole, None]:
+    """
+    Create a hole using data.well-sections collection
+    :param previous_casings: previous casings data
+    :param drill_sections: well sections data
+    :param casing_bottom_depth: bottom depth of casing in ft
+    :return: a hole
+    """
+    # setting cased-hole sections
+    hole = Hole()
+    previous_casing_bottom_depth = 0
+    if previous_casings:
+        previous_casing_bottom_depth = previous_casings[-1].get("data", {}).get("bottom_depth")
+        hole.set_casings(previous_casings)
+
+    # setting open-hole sections
+    for section in drill_sections:
+        section_data = section.get("data", {})
+        open_hole_top_depth = section_data.get("top_depth")
+        open_hole_bottom_depth = section_data.get("bottom_depth")
+        open_hole_diameter = section_data.get("diameter")
+
+        if previous_casing_bottom_depth <= open_hole_top_depth <= open_hole_bottom_depth <= casing_bottom_depth + Wellbore.DEPTH_THRESHOLD:
+            open_hole = HoleSection(
+                inner_diameter=open_hole_diameter,
+                top_depth=open_hole_top_depth,
+                bottom_depth=open_hole_bottom_depth,
+                hole_type=HoleType.OPEN_HOLE)
+            hole.add_section(open_hole)
+
+    return hole
